==> eslint-plugin-typeorm-typescript-0.4.0.tgz: package/es/rules/enforce-column-types.js <==
import { NodeBuilderFlags } from 'typescript';
import { AST_NODE_TYPES, ESLintUtils, } from '@typescript-eslint/utils';
import { convertArgumentToColumnType, convertTsTypeToColumnType, convertTypeToColumnType, isTypesEqual, typeToString, } from '../utils/columnType.js';
import { findEitherDecoratorArguments, findParentClass } from '../utils/treeTraversal.js';
const createRule = ESLintUtils.RuleCreator((name) => `https://github.com/daniel7grant/eslint-plugin-typeorm-typescript#typeorm-typescript${name}`);
const enforceColumnTypes = createRule({
    name: 'enforce-column-types',
    defaultOptions: [],
    meta: {
        type: 'problem',
        docs: {
            description: 'TypeORM and TypeScript types should be the same on columns.',
        },
        hasSuggestions: true,
        messages: {
            typescript_typeorm_column_mismatch: 'Type of {{ propertyName }}{{ className }} is not matching the TypeORM column type{{ expectedValue }}.',
            typescript_typeorm_column_suggestion: 'Change the type of {{ propertyName }} to {{ expectedValue }}.',
        },
        schema: [],
    },
    create(context) {
        return {
            PropertyDefinition(node) {
                var _a;
                const columnArguments = findEitherDecoratorArguments(node.decorators, [
                    'Column',
                    'PrimaryColumn',
                    'PrimaryGeneratedColumn',
                    'CreateDateColumn',
                    'UpdateDateColumn',
                    'DeleteDateColumn',
                    'VersionColumn',
                ]);
                if (!columnArguments || !node.typeAnnotation) {
                    return;
                }
                const [column, colArguments] = columnArguments;
                const typeormType = convertArgumentToColumnType(column, colArguments);
                const { typeAnnotation } = node.typeAnnotation;
                let typescriptType;
                let services;
                let checker;
                try {
                    services = ESLintUtils.getParserServices(context);
                    checker = services.program.getTypeChecker();
                }
                catch (_b) {
                    // No typechecker found, continue with typeless
                }
                if (services && checker) {
                    const type = services.getTypeAtLocation(node);
                    const typeNode = checker.typeToTypeNode(type, undefined, NodeBuilderFlags.None);
                    if (typeNode) {
                        typescriptType = convertTsTypeToColumnType(typeNode, checker);
                    }
                    else {
                        typescriptType = convertTypeToColumnType(typeAnnotation);
                    }
                }
                else {
                    typescriptType = convertTypeToColumnType(typeAnnotation);
                }
                if (!isTypesEqual(typeormType, typescriptType)) {
                    const fixReplace = typeToString(typeormType, typescriptType);
                    // Construct strings for error message
                    const propertyName = ((_a = node.key) === null || _a === void 0 ? void 0 : _a.type) === AST_NODE_TYPES.Identifier ? node.key.name : 'property';
                    const classObject = findParentClass(node);
                    const className = (classObject === null || classObject === void 0 ? void 0 : classObject.id) ? ` in ${classObject.id.name}` : '';
                    const expectedValue = fixReplace ? ` (expected type: ${fixReplace})` : '';
                    // Report the error
                    context.report({
                        node,
                        messageId: 'typescript_typeorm_column_mismatch',
                        data: {
                            className,
                            propertyName,
                            expectedValue,
                        },
                        suggest: fixReplace
                            ? [
                                {
                                    messageId: 'typescript_typeorm_column_suggestion',
                                    fix: (fixer) => fixer.replaceText(typeAnnotation, fixReplace),
                                    data: {
                                        propertyName,
                                        expectedValue: fixReplace,
                                    },
                                },
                            ]
                            : undefined,
                        loc: node.loc,
                    });
                }
            },
        };
    },
});
export default enforceColumnTypes;

==> eslint-plugin-typeorm-typescript-0.5.0.tgz: package/es/rules/enforce-column-types.js <==
import { NodeBuilderFlags } from 'typescript';
import { AST_NODE_TYPES, ESLintUtils, } from '@typescript-eslint/utils';
import { convertArgumentToColumnType, convertTsTypeToColumnType, convertTypeToColumnType, isTypesEqual, typeToString, } from '../utils/columnType.js';
import { findEitherDecoratorArguments, findParentClass } from '../utils/treeTraversal.js';
const createRule = ESLintUtils.RuleCreator((name) => `https://github.com/daniel7grant/eslint-plugin-typeorm-typescript#typeorm-typescript${name}`);
const enforceColumnTypes = createRule({
    name: 'enforce-column-types',
    defaultOptions: [{}],
    meta: {
        type: 'problem',
        docs: {
            description: 'TypeORM and TypeScript types should be the same on columns.',
        },
        hasSuggestions: true,
        messages: {
            typescript_typeorm_column_mismatch: 'Type of {{ propertyName }}{{ className }} is not matching the TypeORM column type{{ expectedValue }}.',
            typescript_typeorm_column_mismatch_weird: 'Type of {{ propertyName }}{{ className }} should be string, as decimals and bigints are encoded as strings by PostgreSQL and MySQL drivers. If you are using SQLite, change the driver option to sqlite.',
            typescript_typeorm_column_suggestion: 'Change the type of {{ propertyName }} to {{ expectedValue }}.',
        },
        schema: [
            {
                type: 'object',
                properties: {
                    driver: {
                        type: 'string',
                        enum: ['postgres', 'mysql', 'sqlite'],
                    },
                },
                additionalProperties: false,
            },
        ],
    },
    create(context) {
        return {
            PropertyDefinition(node) {
                var _a, _b, _c;
                const columnArguments = findEitherDecoratorArguments(node.decorators, [
                    'Column',
                    'PrimaryColumn',
                    'PrimaryGeneratedColumn',
                    'CreateDateColumn',
                    'UpdateDateColumn',
                    'DeleteDateColumn',
                    'VersionColumn',
                ]);
                if (!columnArguments || !node.typeAnnotation) {
                    return;
                }
                const [column, colArguments] = columnArguments;
                const typeormType = convertArgumentToColumnType(column, colArguments, (_b = (_a = context.options) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.driver);
                const { typeAnnotation } = node.typeAnnotation;
                let typescriptType;
                let services;
                let checker;
                try {
                    services = ESLintUtils.getParserServices(context);
                    checker = services.program.getTypeChecker();
                }
                catch (_d) {
                    // No typechecker found, continue with typeless
                }
                if (services && checker) {
                    const type = services.getTypeAtLocation(node);
                    const typeNode = checker.typeToTypeNode(type, undefined, NodeBuilderFlags.None);
                    if (typeNode) {
                        typescriptType = convertTsTypeToColumnType(typeNode, checker);
                    }
                    else {
                        typescriptType = convertTypeToColumnType(typeAnnotation);
                    }
                }
                else {
                    typescriptType = convertTypeToColumnType(typeAnnotation);
                }
                if (!isTypesEqual(typeormType, typescriptType)) {
                    const fixReplace = typeToString(typeormType, typescriptType);
                    // Construct strings for error message
                    const propertyName = ((_c = node.key) === null || _c === void 0 ? void 0 : _c.type) === AST_NODE_TYPES.Identifier ? node.key.name : 'property';
                    const classObject = findParentClass(node);
                    const className = (classObject === null || classObject === void 0 ? void 0 : classObject.id) ? ` in ${classObject.id.name}` : '';
                    const expectedValue = fixReplace ? ` (expected type: ${fixReplace})` : '';
                    // Report the error
                    context.report({
                        node,
                        messageId: 'typescript_typeorm_column_mismatch',
                        data: {
                            className,
                            propertyName,
                            expectedValue,
                        },
                        suggest: fixReplace
                            ? [
                                {
                                    messageId: 'typescript_typeorm_column_suggestion',
                                    fix: (fixer) => fixer.replaceText(typeAnnotation, fixReplace),
                                    data: {
                                        propertyName,
                                        expectedValue: fixReplace,
                                    },
                                },
                            ]
                            : undefined,
                        loc: node.loc,
                    });
                }
            },
        };
    },
});
export default enforceColumnTypes;
